# CHANGELOG

<!-- version list -->

## v1.1.2 (2025-09-03)

### Enhancement

- Add badges, add autopublish action
  ([`042ca5a`](https://github.com/bartekmp/pharmaradar/commit/042ca5af9b74b2252acff66084c9d0987030974f))


## v1.1.1 (2025-09-03)

### Enhancement

- Freeze build and twine packages
  ([`f8c01af`](https://github.com/bartekmp/pharmaradar/commit/f8c01afffd2be7064cb366635d7bc80d3bdd7419))


## v1.1.0 (2025-08-22)

### Feature

- Add selective fields update method
  ([`55fe226`](https://github.com/bartekmp/pharmaradar/commit/55fe226d4aef26ecd6e9efe7d6231c32ff3c4fa2))


## v1.0.2 (2025-08-20)

### Enhancement

- Update readme, remove unused file
  ([`23f66fc`](https://github.com/bartekmp/pharmaradar/commit/23f66fcd73f83f3645962eb39279e18a92f7649f))


## v1.0.1 (2025-08-19)

### Bug Fixes

- Don't run builds on tag releases
  ([`a8b9e8e`](https://github.com/bartekmp/pharmaradar/commit/a8b9e8e7ad33ae38374e866600bde332d8348fbb))

- Use right semver option
  ([`10258b5`](https://github.com/bartekmp/pharmaradar/commit/10258b5dd97b9747cd480da60de48a5350f44f1a))


## v1.0.0 (2025-08-19)

- Initial Release
